﻿//-----------------------------------------------------------------------
// <copyright file="StateNames.cs" company="Eclectrics, LLC">
//     Copyright © 2012 Eclectrics, LLC. All rights reserved.
// </copyright>
//
// Free for all uses under the Creative Commons Attribution 3.0 United 
// Stated License.
//-----------------------------------------------------------------------

namespace Eclectrics.NationalWeatherServiceLibrary
{
    using System.Collections.Generic;
    using System.IO;
    using System.Xml;

    /// <summary>
    /// Encapsulates a collection of US state names.
    /// </summary>
    internal class StateNames
    {
        /// <summary>
        /// The collection of states keyed by abbreviation
        /// </summary>
        private readonly Dictionary<string, string> states = new Dictionary<string, string>();

        /// <summary>
        /// Initializes a new instance of the StateNames class.
        /// </summary>
        public StateNames()
        {
            using (var reader = new StreamReader("StateNames.xml"))
            {
                var doc = new XmlDocument();
                doc.Load(reader);

                if (doc.DocumentElement != null)
                {
                    var stateNodes = doc.DocumentElement.SelectNodes("state");
                    if (stateNodes != null)
                    {
                        foreach (XmlNode stateNode in stateNodes)
                        {
                            if (stateNode.Attributes != null)
                            {
                                var stateName = stateNode.Attributes["name"].InnerText;
                                var stateAbbr = stateNode.Attributes["abbr"].InnerText;
                                if (!string.IsNullOrEmpty(stateName) && !string.IsNullOrEmpty(stateAbbr) && !this.states.ContainsKey(stateAbbr))
                                {
                                    this.states.Add(stateAbbr, stateName);
                                }
                            }
                        }
                    }
                }
            }
        }

        /// <summary>
        /// Convert a standard USPS state abbreviation into the full state name.
        /// </summary>
        /// <param name="abbreviation">abbreviation of requested state</param>
        /// <returns>full state name string</returns>
        public string Name(string abbreviation)
        {
            var name = abbreviation;
            if (this.states.ContainsKey(abbreviation))
            {
                name = this.states[abbreviation];
            }

            return name;
        }
    }
}
