﻿//-----------------------------------------------------------------------
// <copyright file="SimpleTextMessageEncoderBindingElementExtensionElement.cs" company="Eclectrics, LLC">
//     Copyright © 2012 Eclectrics, LLC. All rights reserved.
// </copyright>
//
// The intellectual property contained in this class belongs to Microsoft.
//  
// This document is free for all uses under the Creative Commons Attribution 
// 3.0 United Stated License.
//-----------------------------------------------------------------------
// This code is from the Microsoft WCF sample that can be found here:
// http://msdn.microsoft.com/en-us/library/ms751486(VS.85).aspx

namespace SimpleTextMessageEncoderLibrary
{
    using System;
    using System.ComponentModel;
    using System.Configuration;
    using System.ServiceModel.Channels;
    using System.ServiceModel.Configuration;
    using System.Xml;

    /// <summary>
    /// Initializes an instance of the SimpleTExtMessageEncoderBindingElementExtensionElement
    /// class. SimpleTextMessageEncoderBindingElementExtensionElement allows the use of our 
    /// SimpleTextMessageEncoder from a config file.
    /// </summary>
    public class SimpleTextMessageEncoderBindingElementExtensionElement : BindingElementExtensionElement
    {
        /// <summary>
        /// Gets the type of this binding element.
        /// </summary>
        public override Type BindingElementType
        {
            get { return typeof(SimpleTextMessageEncoderBindingElement); }
        }

        /// <summary>
        /// Gets or sets the MessageVersion
        /// </summary>
        [ConfigurationProperty(ConfigurationStrings.MessageVersion, DefaultValue = ConfigurationStrings.DefaultMessageVersion)]
        [TypeConverter(typeof(MessageVersionConverter))]
        public MessageVersion MessageVersion
        {
            get { return (MessageVersion)base[ConfigurationStrings.MessageVersion]; }
            set { base[ConfigurationStrings.MessageVersion] = value; }
        }

        /// <summary>
        /// Gets or sets the media type.
        /// </summary>
        [ConfigurationProperty(ConfigurationStrings.MediaType, DefaultValue = ConfigurationStrings.DefaultMediaType)]
        public string MediaType
        {
            get { return (string)base[ConfigurationStrings.MediaType]; }
            set { base[ConfigurationStrings.MediaType] = value; }
        }

        /// <summary>
        /// Gets or sets the encoding.
        /// </summary>
        [ConfigurationProperty(ConfigurationStrings.Encoding, DefaultValue = ConfigurationStrings.DefaultEncoding)]
        public string Encoding
        {
            get { return (string)base[ConfigurationStrings.Encoding]; }
            set { base[ConfigurationStrings.Encoding] = value; }
        }

        /// <summary>
        /// Gets the XmlDictionaryReaderQuotas.
        /// </summary>
        [ConfigurationProperty(ConfigurationStrings.ReaderQuotas)]
        public XmlDictionaryReaderQuotasElement ReaderQuotasElement
        {
            get { return (XmlDictionaryReaderQuotasElement)base[ConfigurationStrings.ReaderQuotas]; }
        }

        /// <summary>
        /// Applies the content of the specified binding element to this binding configuration element.
        /// </summary>
        /// <param name="bindingElement">a binding element</param>
        public override void ApplyConfiguration(BindingElement bindingElement)
        {
            base.ApplyConfiguration(bindingElement);
            var binding = (SimpleTextMessageEncoderBindingElement)bindingElement;
            binding.MessageVersion = this.MessageVersion;
            binding.MediaType = this.MediaType;
            binding.Encoding = this.Encoding;
            this.ApplyConfiguration(binding.ReaderQuotas);
        }

        /// <summary>
        /// Create our custom binding element.
        /// </summary>
        /// <returns>the new BindingElement</returns>
        protected override BindingElement CreateBindingElement()
        {
            var binding = new SimpleTextMessageEncoderBindingElement();
            this.ApplyConfiguration(binding);
            return binding;
        }

        /// <summary>
        /// Applies the specified XmlDictionaryReaderQuotas to this binding configuration element.
        /// </summary>
        /// <param name="readerQuotas">a XmlDictionaryReaderQuotas</param>
        private void ApplyConfiguration(XmlDictionaryReaderQuotas readerQuotas)
        {
            if (readerQuotas == null)
            {
                throw new ArgumentNullException("readerQuotas");
            }

            if (this.ReaderQuotasElement.MaxDepth != 0)
            {
                readerQuotas.MaxDepth = this.ReaderQuotasElement.MaxDepth;
            }

            if (this.ReaderQuotasElement.MaxStringContentLength != 0)
            {
                readerQuotas.MaxStringContentLength = this.ReaderQuotasElement.MaxStringContentLength;
            }

            if (this.ReaderQuotasElement.MaxArrayLength != 0)
            {
                readerQuotas.MaxArrayLength = this.ReaderQuotasElement.MaxArrayLength;
            }

            if (this.ReaderQuotasElement.MaxBytesPerRead != 0)
            {
                readerQuotas.MaxBytesPerRead = this.ReaderQuotasElement.MaxBytesPerRead;
            }

            if (this.ReaderQuotasElement.MaxNameTableCharCount != 0)
            {
                readerQuotas.MaxNameTableCharCount = this.ReaderQuotasElement.MaxNameTableCharCount;
            }
        }
    }
}
