﻿//-----------------------------------------------------------------------
// <copyright file="GetCurrentConditionsResult.cs" company="Eclectrics, LLC">
//     Copyright © 2012 Eclectrics, LLC. All rights reserved.
// </copyright>
//
// Free for all uses under the Creative Commons Attribution 3.0 United 
// Stated License.
//-----------------------------------------------------------------------

namespace TestFromZip
{
    /// <summary>
    /// Encapsulates the results from a call to GetCurrentConditions
    /// </summary>
    internal class GetCurrentConditionsResult
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="GetCurrentConditionsResult"/> class.
        /// </summary>
        /// <param name="success">if set to <c>true</c> [success].</param>
        /// <param name="currentConditions">The current conditions.</param>
        /// <param name="stationName">Name of the station.</param>
        /// <param name="distanceToStation">The distance to station.</param>
        /// <param name="status">The status.</param>
        public GetCurrentConditionsResult(bool success, string currentConditions, string stationName, double distanceToStation, string status)
        {
            this.Success = success;
            this.CurrentConditions = currentConditions;
            this.StationName = stationName;
            this.DistanceToStation = distanceToStation;
            this.Status = status;
        }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="GetCurrentConditionsResult"/> is success.
        /// </summary>
        /// <value>
        ///   <c>true</c> if success; otherwise, <c>false</c>.
        /// </value>
        public bool Success { get; set; }

        /// <summary>
        /// Gets or sets the current conditions.
        /// </summary>
        /// <value>
        /// The current conditions.
        /// </value>
        public string CurrentConditions { get; set; }

        /// <summary>
        /// Gets or sets the name of the station.
        /// </summary>
        /// <value>
        /// The name of the station.
        /// </value>
        public string StationName { get; set; }

        /// <summary>
        /// Gets or sets the distance to station.
        /// </summary>
        /// <value>
        /// The distance to station.
        /// </value>
        public double DistanceToStation { get; set; }

        /// <summary>
        /// Gets or sets the status.
        /// </summary>
        /// <value>
        /// The status.
        /// </value>
        public string Status { get; set; }
    }
}
