﻿//-----------------------------------------------------------------------------
// <copyright file="XmlTreeNodeDetails.cs" company="Eclectrics, LLC">
//     © 2012 Eclectrics, LLC. All rights reserved.
// </copyright>
// Free for all uses under the Creative Commons Attribution 3.0 United States License
// http://creativecommons.org/licenses/by/3.0/us/
//-----------------------------------------------------------------------------

namespace Eclectrics.XmlToolsLibrary
{
    using System.Collections.Generic;

    /// <summary>
    /// A container 
    /// </summary>
    internal class XmlTreeNodeDetails
    {
        /// <summary>
        /// The list of attributes.
        /// </summary>
        private readonly List<string> attributes = new List<string>();

        /// <summary>
        /// True if the width is dirty.
        /// </summary>
        private bool widthIsDirty = true;

        /// <summary>
        /// Gets or sets the name of an Xml element.
        /// </summary>
        public string ElementTag { get; set; }

        /// <summary>
        /// Gets the collection of attributes and values for an Xml element.
        /// </summary>
        public List<string> Attributes
        {
            get { return this.attributes; }
        }

        /// <summary>
        /// Gets or sets the content of an Xml element.
        /// </summary>
        public string Content { get; set; }

        /// <summary>
        /// Gets or sets the total required width in pixels needed to draw all the XmlTreeNode text.
        /// </summary>
        public int Width { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether the drawing code that the text content has changed. 
        /// Drawing code uses this value to determine if it needs to recalculate the width of the
        /// text when drawing the highlighted background of the selected element.
        /// </summary>
        public bool WidthIsDirty
        {
            get { return this.widthIsDirty; }
            set { this.widthIsDirty = value; }
        }
    }
}
